@@ -13,6 +13,7 @@
 #include <sys/time.h>
 
 #include "af_lane.h"
+#include "lec.h"     /* for LAN_MTU */
 
 void conn_call_callbacks(void);
 void conn_get_fds(fd_set *fds);
@@ -21,8 +22,10 @@ int conn_check_incoming(fd_set *fds);
 int conn_create_listensocket(HANDLE sap_context, HANDLE conn_context,
 			     unsigned short blli_codepoint,
 			     const char *qos_spec,
-			     HANDLE *p_conn_handle);
+			     LAN_MTU mtu);
 int conn_set_kernel_socket(int fd);
+int maxframe2maxsdu(LAN_MTU mtu);
+
 /*
 void conn_convert_to_data_vcc(HANDLE conn_handle);
 */
