@@ -150,4 +150,25 @@ int un_send(const UN_CTX *ctx,void *buf,int len);
  * negative value on error.
  */
 
+
+/* ------------------------- IP address operations ------------------------- */
+
+
+#include <stdint.h>
+#include <netinet/in.h>
+
+
+#define T2I_NAME	1	/* do a name lookup */
+#define T2I_ERROR	2	/* print error messages */
+
+uint32_t text2ip(const char *text,const char *component,int flags);
+
+/*
+ * Converts a text string to an IP address. If resolution fails, text2ip
+ * returns INADDR_NONE. If T2I_ERROR is set, errors messages are printed. If
+ * component is non-NULL, they are logged using diag(). Otherwise, they are
+ * printed on standard error. Note that T2I_NAME uses gethostbyname() which
+ * may attempt resolution via DNS or NIS.
+ */
+
 #endif
