@@ -170,7 +170,8 @@ static BUFFER *build_pdu(SSCOP_DSC *dsc,unsigned char type,void *data,
 	case SSCOP_BGN:
 	case SSCOP_RS:
 	case SSCOP_ER:
-	    *trailer++ = SSCOP_TRAIL(0,0,dsc->vt_sq);
+	    *trailer++ = dsc->mode == sscop_qsaal1 ? SSCOP_TRAIL(0,0,0) :
+	      SSCOP_TRAIL(0,0,dsc->vt_sq);
 	    *trailer++ = SSCOP_TRAIL(type,pad,dsc->vr_mr);
 	    break;
 	case SSCOP_BGAK:
@@ -392,6 +393,7 @@ static void initialize_state_variables(SSCOP_DSC *dsc) /* 20.49 */
 
 static int detect_retransmission(SSCOP_DSC *dsc,int sq) /* 20.50 */
 {
+    if (dsc->mode == sscop_qsaal1) return 0;
     if (dsc->vr_sq == sq) return 1;
     dsc->vr_sq = sq;
     return 0;
@@ -1670,7 +1672,8 @@ void sscop_maa_data(SSCOP_DSC *dsc,void *buffer,int size) /* 20.47-48 */
 }
 
 
-void start_sscop(SSCOP_DSC *dsc,SSCOP_USER_OPS *ops,void *user_data)
+void start_sscop(SSCOP_DSC *dsc,SSCOP_USER_OPS *ops,void *user_data,
+  SSCOP_MODE mode)
 {
     static int initialize = 1;
 
@@ -1681,6 +1684,7 @@ void start_sscop(SSCOP_DSC *dsc,SSCOP_USER_OPS *ops,void *user_data)
     }
     dsc->ops = ops;
     dsc->user = user_data;
+    dsc->mode = mode;
     dsc->vt_sq = dsc->vr_sq = 0; /* 20.5 */
     dsc->clear_buffers = 1;
     dsc->state = sscop_idle;
